---
layout: default
title: Overview
nav_order: 1
---

# Encode geographic data as topology in Python!

Topojson is a library that is capable of creating a topojson encoded format of merely any geographical object in Python.

With topojson it is possible to reduce the size of your geographical data. Mostly by orders of magnitude. It is able to do so through:

- Eliminating redundancy through computation of a topology
- Fixed-precision integer encoding of coordinates and
- Simplification and quantization of arcs

## Getting Started

- [Installation](installation)
- [Example usage](example-usage)

## User Guide

- [How it works](how-it-works)
- [API-reference](api-reference)

## Bug Reports & Questions

- [Contributing](contributing)

Topojson is BSD-licensed and the source is available on GitHub. If any questions or issues come up as you use topojson, please get in touch via Git Issues.
